function varargout = select_a_file_please(varargin)
% SELECT_A_FILE_PLEASE MATLAB code for select_a_file_please.fig
%      SELECT_A_FILE_PLEASE, by itself, creates a new SELECT_A_FILE_PLEASE or raises the existing
%      singleton*.
%
%      H = SELECT_A_FILE_PLEASE returns the handle to a new SELECT_A_FILE_PLEASE or the handle to
%      the existing singleton*.
%
%      SELECT_A_FILE_PLEASE('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in SELECT_A_FILE_PLEASE.M with the given input arguments.
%
%      SELECT_A_FILE_PLEASE('Property','Value',...) creates a new SELECT_A_FILE_PLEASE or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before select_a_file_please_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to select_a_file_please_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help select_a_file_please

% Last Modified by GUIDE v2.5 24-Nov-2011 00:38:01

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @select_a_file_please_OpeningFcn, ...
                   'gui_OutputFcn',  @select_a_file_please_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before select_a_file_please is made visible.
function select_a_file_please_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to select_a_file_please (see VARARGIN)

% Choose default command line output for select_a_file_please
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes select_a_file_please wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = select_a_file_please_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

delete(gcf);
AnalysisGSP;
